#=======================================================================
# FILE: install_update_texlive.sh
# USAGE: Run from the terminal
# DESCRIPTION: Automatic install/update of TeXLive 2011
# OPTIONS: —
# REQUIREMENTS: Ubuntu or OpenSuse
# BUGS: —
# NOTES: Website: http://alexkrispin.wordpress.com/
# AUTHORS: Alexandre Krispin, k.m.alexandre@gmail.com, Matthew D. Mower, Cédrick Copol
# UPDATE: Danial Behzadi
# COMPANY: —
# CREATED: 2010 Oct 11, 20:25:43 UTC
# REVISION: Sat 04 Feb 2012 05:27:42 PM
#=======================================================================
#! /bin/bash

sudo -k

#-------------------------------------------------------------------------------
#  Translations
#-------------------------------------------------------------------------------
#{{{
echo $LANG | grep -i fr;
if [ "$?" == "0" ]; then

#La langue est le français {{{
    SELECT="Sélectionnez"
    CHOISE="Choix"

    IN_UP_TITLE="Installation ou mise à jour"
    IN_UP_TEXT="Souhaitez-vous faire une (ré)installation ou une mise à jour ?"
    IN_UP_TRUE="Installation"
    IN_UP_FALS="Mise à jour"
    DISC_TITLE="Espace disque"
    DISC_TEXT="Une installation complète nécessite ~2,3GB d'espace libre. Appuyer sur Oui pour continuer ou Non pour quitter."
    PASSWD_TITLE="Mot de passe"
    PASSWD_TEXT="Votre mot de passe est nécessaire pour continuer."
    BAD_PASSWD_TITLE="Mot de passe invalide"
    BAD_PASSWD_TEXT="Mot de passe invalide. Veuillez recomposer celui-ci :"
    EXIT_BAD_PASSWD="Désolé 3 mauvais mot de passe donné.\n$0 va se fermer."
    INFO_TEXT="L'installation va commencer et une fenêtre s'ouvrira. Pour exemple voir\nhttp://www.tug.org/texlive/doc/texlive-common/install-lnx-main.png\n\nVérifiez la taille du papier (A4 en général) puis cliquer sur 'Install TeX Live' pour continuer. (Notez que ce script ne fonctionne correctement qu'avec le dossier d'installation par défaut de TeX Live)"
    INFO_TITLE="Dernière notification avant installation"
    FILE_TITLE="Fichiers d'installation"
    FILE_TEXT="Voulez-vous conserver les fichiers d'installation téléchargés ? (Ils ne sont pas nécessaire au fonctionnement de TeX Live)"
    FONT_TITLE="Remarque informative"
    FONT_TEXT="Les fontes vont maintenant être installées."
    IN_END_TITLE="Installation terminée"
    IN_END_TEXT="L'installation est terminée. Vous pouvez périodiquement relancer ce script plus tard afin de mettre à jour votre distribution. Pour appliquer les modifications veuillez fermer votre session puis la réouvrir."
    UP_END_TITLE="Mise à jour terminé"
    UP_END_TEXT="TeXlive a été mis à jour."
    #}}}
else
# Default language is English {{{
    SELECT="Select"
    CHOISE="Choice"

    IN_UP_TITLE="Install or update"
    IN_UP_TEXT="New install or update?"
    IN_UP_TRUE="Install"
    IN_UP_FALS="Update"
    DISC_TITLE="Disc  space"
    DISC_TEXT="A full  installation requires  ~2.3GB of
disc space. Press Yes to preceed or No to halt"
    PASSWD_TITLE="Password"
    PASSWD_TEXT="Your password is needed to continue:"
    BAD_PASSWD_TITLE="Invalid password"
    BAD_PASSWD_TEXT="Invalid password. Please re-enter a sudo capable password:"
    EXIT_BAD_PASSWD="Sorry 3 incorrect password attempts.\n $0 will be closed"
    INFO_TEXT="The installation process will begin and a window will appear. See here for an example:\nhttp://www.tug.org/texlive/doc/texlive-common/install-lnx-main.png\n\nCheck that paper size is correct. Then click 'Install TeX Live' to continue. (Note that this script is hard coded to work only with the default installation directory)"
    INFO_TITLE="Last notification before installation"
    FILE_TITLE="Install files"
    FILE_TEXT="Would you like to keep the downloaded installation files? (They are not necessary to use TeXLive)"
    FONT_TITLE="Information notice"
    FONT_TEXT="Now fonts will be configured."
    IN_END_TITLE="Installation finished"
    IN_END_TEXT="Installation finished. You can periodically run this script at later dates to update your distribution. In order for environment variables to be set, you still need to log out and log back in"
    UP_END_TITLE="Update finished"
    UP_END_TEXT="TeXlive has been updated."
fi
#}}}
#}}}

#===  FUNCTION  ================================================================
#          NAME:  ask_passwd
#   DESCRIPTION:  ask the password, and stop if there is more than 3 errors
#    PARAMETERS:  
#       RETURNS:  
#===============================================================================
# {{{
ask_passwd() 
{
    PASSWORD=`zenity --title='$PASSWD_TITLE' --text="$PASSWD_TEXT" --hide-text --entry`
    if [ "$?" -eq "1" ] ; then
	exit
    fi
    # Count of the times you try to enter the password
    nb_inputpwd=1 
    echo $PASSWORD | sudo -S echo -e '\nPassword test.'
    while [ "$?" -eq "1" ]; do
    # Only 3 errors are authorized
	if [ "$nb_inputpwd" -eq "3" ]; then
	    zenity --title='$BAD_PASSWD_TITLE' --text="$EXIT_BAD_PASSWD" --error
	    exit
	else
	    PASSWORD=`zenity --title='$BAD_PASSWD_TITLE' --text="$BAD_PASSWD_TEXT" --hide-text --entry`
	    if [ "$?" -eq "1" ]; then
		exit
	    fi
            # Incrementation
	    nb_inputpwd=$(( nb_inputpwd+1 ))
	    echo $PASSWORD | sudo -S echo -e '\nPassword test.'
	fi
    done
}
#}}}

#-------------------------------------------------------------------------------
#  Select platform automatically, i386 or x64 {{{
#-------------------------------------------------------------------------------
PLATFORM=`uname -m`
case "$PLATFORM" in
    i386 | i486 | i586 | i686 | k7) BITTAG="i386-linux";;
    x86_64 | EM64T) BITTAG="x86_64-linux";;
    *)echo -e "$BAD_PLAT_TEXT" | zenity --title="$BAD_PLAT_TITLE" --text-info --width 500 --height 200;exit;;
esac
#}}}

#-------------------------------------------------------------------------------
#  Install or Update choice {{{
#-------------------------------------------------------------------------------
INSTALL_OR_UPDATE=$(zenity --title="$IN_UP_TITLE" --text="$IN_UP_TEXT" --list --radiolist --column "$SELECT" --column "$CHOISE" true "$IN_UP_TRUE" false "$IN_UP_FALS")
 if [ "$?" -eq "1" ]
 then
    exit;
 fi
#}}}
#-------------------------------------------------------------------------------
#  Case Install {{{
#-------------------------------------------------------------------------------
case "$INSTALL_OR_UPDATE" in
    "$IN_UP_TRUE")

#-------------------------------------------------------------------------------
#  Select OS {{{
#-------------------------------------------------------------------------------

OS=$(zenity --title="Your OS"\
    --text="Choose your OS:"\
    --list\
    --radiolist\
    --column "Select"\
    --column "Choice"\
    true "Ubuntu"\
    false "ArchLinux"\
    false "OpenSuse")
if [ "$?" -eq "1" ]
then
	exit;
    fi
#}}}

#-------------------------------------------------------------------------------
#  Installing a package for the official install script of TeXLive 2011 {{{
#-------------------------------------------------------------------------------
case "$OS" in
    "Ubuntu") PKGMGR_PERL="apt-get install perl-tk";;
    "SUSE LINUX") PKGMGR_PERL="zypper perl-Tk";;
    "ArchLinux") PKGMGR_PERL="pacman -S perl-tk";;
    *) echo -e "$BAD_OS_TEXT" | zenity --title="$BAD_OS_TITLE" --text-info --width 500 --height 200;exit;;
esac
#}}}

	zenity --question --title="$DISC_TITLE" --text="$DISC_TEXT"
	if [ "$?" -eq "1" ]
	then
	    exit;
	fi

	STARTDIR=$(pwd)

	ask_passwd

	echo $PASSWORD | sudo -S $PKGMGR_PERL

	wget -c http://mirror.ctan.org/systems/texlive/tlnet/install-tl-unx.tar.gz
	tar -xf install-tl-unx.tar.gz

	echo -e "$INFO_TEXT" | zenity --title="$INFO_TITLE" --text-info --width 550 --height 200

	cd $STARTDIR/install-tl-2*
	echo $PASSWORD | sudo -S ./install-tl -gui

	cd $STARTDIR

	zenity --question --title="$FILE_TITLE" --text="$FILE_TEXT"
	if [ "$?" -eq "1" ]
	then
	    rm -rf install-tl*
	fi

	echo -e "\nPATH=/usr/local/texlive/2011/bin/$BITTAG:\$PATH; export
	PATH\nMANPATH=/usr/local/texlive/2011/texmf/doc/man:\$MANPATH; export
	MANPATH\nINFOPATH=/usr/local/texlive/2011/texmf/doc/info:\$INFOPATH; export INFOPATH\n" >> ~/.profile

	zenity --info --title="$FONT_TITLE" --text="$FONT_TEXT"

	echo $PASSWORD | sudo -S cp /usr/local/texlive/2011/texmf-var/fonts/conf/texlive-fontconfig.conf /etc/fonts/conf.d/09-texlive.conf
	echo $PASSWORD | sudo -S fc-cache -fsv

	zenity --info title="$IN_END_TITLE" --text="$IN_END_TEXT"

	;;
esac
#}}}

#-------------------------------------------------------------------------------
#  Case Update {{{
#-------------------------------------------------------------------------------
case "$INSTALL_OR_UPDATE" in
    "$IN_UP_FALS")

	ask_passwd
	
	echo $PASSWORD | sudo -S /usr/local/texlive/2011/bin/$BITTAG/tlmgr update --self
	echo $PASSWORD | sudo -S /usr/local/texlive/2011/bin/$BITTAG/tlmgr update --all
	zenity --info --title="$UP_END_TITLE" --text="$UP_END_TEXT"

	;;
esac
#}}}

exit

#}}}
